aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java')
-rw-r--r--src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java b/src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java
index d34edaf2e..a69480242 100644
--- a/src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java
+++ b/src/jogl/classes/javax/media/opengl/GLOffscreenAutoDrawable.java
@@ -37,19 +37,19 @@ import com.jogamp.opengl.FBObject;
* exposing offscreen functionality.
* <p>
* This class distinguishes itself from {@link GLAutoDrawable}
- * with it's {@link #setSize(int, int)} functionality.
+ * with it's {@link #setSurfaceSize(int, int)} functionality.
* </p>
*/
public interface GLOffscreenAutoDrawable extends GLAutoDrawable, GLSharedContextSetter {
/**
* Resize this auto drawable.
* @param newWidth
* @param newHeight
* @throws NativeWindowException in case the surface could no be locked
* @throws GLException in case of an error during the resize operation
*/
- void setSize(int newWidth, int newHeight) throws NativeWindowException, GLException;
+ void setSurfaceSize(int newWidth, int newHeight) throws NativeWindowException, GLException;
/**
* Set the upstream UI toolkit object.
@@ -37,19 +37,19 @@ import com.jogamp.opengl.FBObject;
public interface GLOffscreenAutoDrawable extends GLAutoDrawable, GLSharedContextSetter {
/**
- * Resize this auto drawable.
- * @param newWidth
- * @param newHeight
+ * Resize this {@link GLAutoDrawable}'s surface
+ * @param newWidth new width in pixel units
+ * @param newHeight new height in pixel units
* @throws NativeWindowException in case the surface could no be locked
* @throws GLException in case of an error during the resize operation